/* Generated by Nim Compiler v2.2.10 */
#define NIM_INTBITS 64
#define NIM_EmulateOverflowChecks

#include "nimbase.h"
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix
typedef struct tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg;
typedef struct tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ;
typedef struct tySequence__6H5Oh5UUvVCLiakt9aTwtUQ tySequence__6H5Oh5UUvVCLiakt9aTwtUQ;
typedef struct tySequence__6H5Oh5UUvVCLiakt9aTwtUQ_Content tySequence__6H5Oh5UUvVCLiakt9aTwtUQ_Content;
typedef struct tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg;
typedef struct tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg;
typedef struct tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA;
typedef struct tySequence__d8ZV4IMgHt9biik9cS9a0hrmg tySequence__d8ZV4IMgHt9biik9cS9a0hrmg;
typedef struct tySequence__d8ZV4IMgHt9biik9cS9a0hrmg_Content tySequence__d8ZV4IMgHt9biik9cS9a0hrmg_Content;
typedef struct tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg;
typedef struct tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw;
typedef struct NimStrPayload NimStrPayload;
typedef struct NimStringV2 NimStringV2;
typedef struct tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA;
typedef struct tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA;
typedef struct tySequence__9ahcSjIErJohSBBFLwuF56Q tySequence__9ahcSjIErJohSBBFLwuF56Q;
typedef struct tySequence__9ahcSjIErJohSBBFLwuF56Q_Content tySequence__9ahcSjIErJohSBBFLwuF56Q_Content;
struct tySequence__6H5Oh5UUvVCLiakt9aTwtUQ {
  NI len; tySequence__6H5Oh5UUvVCLiakt9aTwtUQ_Content* p;
};
typedef NU32 tyArray__PPSU5X9aizf5OJq0lL4Og7A[4];
struct tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg {
	tyArray__PPSU5X9aizf5OJq0lL4Og7A udata;
};
struct tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA {
	NI32 module;
	NI32 item;
};
typedef NU8 tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg;
typedef NU8 tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ;
typedef NU64 tySet_tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A;
struct tySequence__d8ZV4IMgHt9biik9cS9a0hrmg {
  NI len; tySequence__d8ZV4IMgHt9biik9cS9a0hrmg_Content* p;
};
typedef NU8 tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ;
typedef NU8 tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg;
typedef NU16 tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg;
struct NimStrPayload {
	NI cap;
	NIM_CHAR data[SEQ_DECL_SIZE];
};
struct NimStringV2 {
	NI len;
	NimStrPayload* p;
};
struct tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw {
	tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ k;
	tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg storage;
	tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg flags;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* lode;
	NimStringV2 snippet;
};
struct tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg {
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA itemId;
	tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg kind;
	tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ callConv;
	tySet_tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A flags;
	tySequence__d8ZV4IMgHt9biik9cS9a0hrmg sons;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* ownerField;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym;
	NI64 size;
	NI16 align;
	NI16 paddingAtEnd;
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw loc;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typeInst;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA uniqueId;
};
struct tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA {
	NU16 line;
	NI16 col;
	NI32 fileIndex;
};
typedef NU32 tySet_tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw;
typedef NU8 tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw;
struct tySequence__9ahcSjIErJohSBBFLwuF56Q {
  NI len; tySequence__9ahcSjIErJohSBBFLwuF56Q_Content* p;
};
struct tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typField;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info;
	tySet_tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw flags;
	tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw kind;
union{
	struct {
	NI64 intVal;
} _kind_1;
	struct {
	NF floatVal;
} _kind_2;
	struct {
	NimStringV2 strVal;
} _kind_3;
	struct {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym;
} _kind_4;
	struct {
	tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* ident;
} _kind_5;
	struct {
	tySequence__9ahcSjIErJohSBBFLwuF56Q sons;
} _kind_6;
};
};
struct tySequence__6H5Oh5UUvVCLiakt9aTwtUQ_Content { NI cap; NU8 data[SEQ_DECL_SIZE]; };
struct tySequence__d8ZV4IMgHt9biik9cS9a0hrmg_Content { NI cap; tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* data[SEQ_DECL_SIZE]; };
struct tySequence__9ahcSjIErJohSBBFLwuF56Q_Content { NI cap; tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* data[SEQ_DECL_SIZE]; };
N_LIB_PRIVATE N_NIMCALL(tySequence__6H5Oh5UUvVCLiakt9aTwtUQ, toBitSet__nimsets_u73)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* s_p1);
N_LIB_PRIVATE N_NIMCALL(void*, newSeqPayload)(NI cap_p0, NI elemSize_p1, NI elemAlign_p2);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg, firstOrd__types_u1182)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p1);
static N_INLINE(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, elementType__ast_u5331)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* n_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___ast_u3381)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg** dest_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* src_p1);
static N_INLINE(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg**, X5BX5D___ast_u5281)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg** s_p0, NI s_p0Len_0, NI i_p1);
static N_INLINE(NIM_BOOL*, nimErrorFlag)(void);
N_LIB_PRIVATE N_NIMCALL(void, bitSetInit__bitsets_u56)(tySequence__6H5Oh5UUvVCLiakt9aTwtUQ* b_p0, NI length_p1);
N_LIB_PRIVATE N_NIMCALL(NI64, getSize__types_u3411)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p1);
static N_INLINE(NI, len__ast_u3190)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg, getOrdValue__types_u171)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0, tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg onError_p1);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, lteq___int128_u408)(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg a_p0, tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg b_p1);
N_LIB_PRIVATE N_NIMCALL(void, bitSetIncl__bitsets_u23)(tySequence__6H5Oh5UUvVCLiakt9aTwtUQ* x_p0, NI64 elem_p1);
N_LIB_PRIVATE N_NIMCALL(NI64, toInt64__int128_u53)(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg arg_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg, minus___int128_u641)(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg a_p0, tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg b_p1);
N_LIB_PRIVATE N_NIMCALL(void, inc__int128_u338)(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg* a_p0, NU32 y_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg, getOrdValue__types_u167)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u3378)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* dest_p0);
N_LIB_PRIVATE N_NIMCALL(NI64, bitSetCard__bitsets_u190)(tySequence__6H5Oh5UUvVCLiakt9aTwtUQ x_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___pureZtimes_u2620)(tySequence__6H5Oh5UUvVCLiakt9aTwtUQ dest_p0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, bitSetContains__bitsets_u127)(tySequence__6H5Oh5UUvVCLiakt9aTwtUQ x_p0, tySequence__6H5Oh5UUvVCLiakt9aTwtUQ y_p1);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, bitSetEquals__bitsets_u115)(tySequence__6H5Oh5UUvVCLiakt9aTwtUQ x_p0, tySequence__6H5Oh5UUvVCLiakt9aTwtUQ y_p1);
N_LIB_PRIVATE N_NIMCALL(void, bitSetIntersect__bitsets_u104)(tySequence__6H5Oh5UUvVCLiakt9aTwtUQ* x_p0, tySequence__6H5Oh5UUvVCLiakt9aTwtUQ y_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, toTreeSet__nimsets_u92)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tySequence__6H5Oh5UUvVCLiakt9aTwtUQ s_p1, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* settype_p2, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p3);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, newNodeI__ast_u4091)(tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw kind_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, bitSetIn__bitsets_u11)(tySequence__6H5Oh5UUvVCLiakt9aTwtUQ x_p0, NI64 e_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, newIntTypeNode__ast_u5387)(NI64 intVal_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p1);
N_LIB_PRIVATE N_NIMCALL(void, add__ast_u3215)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* father_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* son_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___ast_u3261)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** dest_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* src_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u3252)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, bitSetUnion__bitsets_u71)(tySequence__6H5Oh5UUvVCLiakt9aTwtUQ* x_p0, tySequence__6H5Oh5UUvVCLiakt9aTwtUQ y_p1);
N_LIB_PRIVATE N_NIMCALL(void, bitSetDiff__bitsets_u82)(tySequence__6H5Oh5UUvVCLiakt9aTwtUQ* x_p0, tySequence__6H5Oh5UUvVCLiakt9aTwtUQ y_p1);
N_LIB_PRIVATE N_NIMCALL(void, bitSetSymDiff__bitsets_u93)(tySequence__6H5Oh5UUvVCLiakt9aTwtUQ* x_p0, tySequence__6H5Oh5UUvVCLiakt9aTwtUQ y_p1);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, leValue__astalgo_u79)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* a_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* b_p1);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, sameValue__astalgo_u63)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* a_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* b_p1);
extern NIM_CONST tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg Zero__int128_u8;
extern NIM_BOOL nimInErrorMode__system_u4138;
static N_INLINE(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg**, X5BX5D___ast_u5281)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg** s_p0, NI s_p0Len_0, NI i_p1) {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg** result;
	result = &s_p0[(NI)(s_p0Len_0 - i_p1)];
	return result;
}
static N_INLINE(NIM_BOOL*, nimErrorFlag)(void) {
	NIM_BOOL* result;
	result = (&nimInErrorMode__system_u4138);
	return result;
}
static N_INLINE(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, elementType__ast_u5331)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* n_p0) {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* result;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg** T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	T1_ = (tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg**)0;
	T1_ = X5BX5D___ast_u5281((((*n_p0).sons).p) ? ((*n_p0).sons.p->data) : NIM_NIL, (*n_p0).sons.len, ((NI)1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqcopy___ast_u3381(&result, (*T1_));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NI, len__ast_u3190)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0) {
	NI result;
	NI T1_;
	T1_ = (*n_p0)._kind_6.sons.len;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tySequence__6H5Oh5UUvVCLiakt9aTwtUQ, toBitSet__nimsets_u73)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* s_p1) {
	tySequence__6H5Oh5UUvVCLiakt9aTwtUQ result;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
	tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg first_1;
	tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg j_1;
	NI64 T2_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	colontmpD_ = NIM_NIL;
	result.len = 0; result.p = (tySequence__6H5Oh5UUvVCLiakt9aTwtUQ_Content*) newSeqPayload(0, sizeof(NU8), NIM_ALIGNOF(NU8));
	first_1 = Zero__int128_u8;
	j_1 = Zero__int128_u8;
	colontmpD_ = elementType__ast_u5331((*s_p1).typField);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	first_1 = firstOrd__types_u1182(conf_p0, colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T2_ = (NI64)0;
	T2_ = getSize__types_u3411(conf_p0, (*s_p1).typField);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	bitSetInit__bitsets_u56((&result), ((NI) (T2_)));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NI i_1;
		NI colontmp_;
		NI i_2;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__ast_u3190(s_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		i_2 = ((NI)0);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA5;
				i_1 = i_2;
				{
					if (!((*(*s_p1)._kind_6.sons.p->data[i_1]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)44))) goto LA8_;
					j_1 = getOrdValue__types_u171((*(*s_p1)._kind_6.sons.p->data[i_1])._kind_6.sons.p->data[((NI)0)], first_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					{
						while (1) {
							tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T12_;
							NIM_BOOL T13_;
							tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T14_;
							NI64 T15_;
							T12_ = getOrdValue__types_u171((*(*s_p1)._kind_6.sons.p->data[i_1])._kind_6.sons.p->data[((NI)1)], first_1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
							T13_ = (NIM_BOOL)0;
							T13_ = lteq___int128_u408(j_1, T12_);
							if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
							if (!T13_) goto LA11;
							T14_ = minus___int128_u641(j_1, first_1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
							T15_ = (NI64)0;
							T15_ = toInt64__int128_u53(T14_);
							if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
							bitSetIncl__bitsets_u23((&result), T15_);
							if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
							inc__int128_u338((&j_1), ((NU32)1));
							if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						} LA11: ;
					}
				}
				goto LA6_;
LA8_: ;
				{
					tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T17_;
					tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T18_;
					NI64 T19_;
					T17_ = getOrdValue__types_u167((*s_p1)._kind_6.sons.p->data[i_1]);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					T18_ = minus___int128_u641(T17_, first_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					T19_ = (NI64)0;
					T19_ = toInt64__int128_u53(T18_);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					bitSetIncl__bitsets_u23((&result), T19_);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				}
LA6_: ;
				i_2 += ((NI)1);
			} LA5: ;
		}
	}
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3378(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI64, cardSet__nimsets_u191)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* a_p1) {
	NI64 result;
	tySequence__6H5Oh5UUvVCLiakt9aTwtUQ x_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI64)0;
	x_1.len = 0; x_1.p = NIM_NIL;
	x_1 = toBitSet__nimsets_u73(conf_p0, a_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	result = bitSetCard__bitsets_u190(x_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		eqdestroy___pureZtimes_u2620(x_1);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, containsSets__nimsets_u159)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* a_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* b_p2) {
	NIM_BOOL result;
	tySequence__6H5Oh5UUvVCLiakt9aTwtUQ x_1;
	tySequence__6H5Oh5UUvVCLiakt9aTwtUQ y_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NIM_BOOL)0;
	x_1.len = 0; x_1.p = NIM_NIL;
	y_1.len = 0; y_1.p = NIM_NIL;
	x_1 = toBitSet__nimsets_u73(conf_p0, a_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	y_1 = toBitSet__nimsets_u73(conf_p0, b_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	result = bitSetContains__bitsets_u127(x_1, y_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		eqdestroy___pureZtimes_u2620(y_1);
		eqdestroy___pureZtimes_u2620(x_1);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, equalSets__nimsets_u166)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* a_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* b_p2) {
	NIM_BOOL result;
	tySequence__6H5Oh5UUvVCLiakt9aTwtUQ x_1;
	tySequence__6H5Oh5UUvVCLiakt9aTwtUQ y_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NIM_BOOL)0;
	x_1.len = 0; x_1.p = NIM_NIL;
	y_1.len = 0; y_1.p = NIM_NIL;
	x_1 = toBitSet__nimsets_u73(conf_p0, a_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	y_1 = toBitSet__nimsets_u73(conf_p0, b_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	result = bitSetEquals__bitsets_u115(x_1, y_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		eqdestroy___pureZtimes_u2620(y_1);
		eqdestroy___pureZtimes_u2620(x_1);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, toTreeSet__nimsets_u92)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tySequence__6H5Oh5UUvVCLiakt9aTwtUQ s_p1, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* settype_p2, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p3) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* elemType_1;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_1;
	NI64 a_1;
	NI64 b_1;
	NI64 e_1;
	NI64 first_1;
	tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T2_;
NIM_BOOL oldNimErrFin11_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	elemType_1 = NIM_NIL;
	n_1 = NIM_NIL;
	a_1 = (NI64)0;
	b_1 = (NI64)0;
	e_1 = (NI64)0;
	first_1 = (NI64)0;
	eqcopy___ast_u3381(&elemType_1, (*settype_p2).sons.p->data[((NI)0)]);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T2_ = firstOrd__types_u1182(conf_p0, elemType_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	first_1 = toInt64__int128_u53(T2_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	result = newNodeI__ast_u4091(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)39), info_p3);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	eqcopy___ast_u3381(&(*result).typField, settype_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	(*result).info = info_p3;
	e_1 = IL64(0);
	{
		while (1) {
			NI T5_;
			T5_ = s_p1.len;
			if (!(e_1 < ((NI64) ((NI)(T5_ * ((NI)8)))))) goto LA4;
			{
				NIM_BOOL T8_;
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* aa_1;
				T8_ = (NIM_BOOL)0;
				T8_ = bitSetIn__bitsets_u11(s_p1, e_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				if (!T8_) goto LA9_;
				aa_1 = NIM_NIL;
				a_1 = e_1;
				b_1 = e_1;
				{
					while (1) {
						b_1 += ((NI)1);
						{
							NIM_BOOL T16_;
							NI T17_;
							NIM_BOOL T19_;
							T16_ = (NIM_BOOL)0;
							T17_ = s_p1.len;
							T16_ = (((NI64) ((NI)(T17_ * ((NI)8)))) <= b_1);
							if (T16_) goto LA18_;
							T19_ = (NIM_BOOL)0;
							T19_ = bitSetIn__bitsets_u11(s_p1, b_1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
							T16_ = !(T19_);
LA18_: ;
							if (!T16_) goto LA20_;
							goto LA12;
						}
LA20_: ;
					}
				} LA12: ;
				b_1 -= ((NI)1);
				aa_1 = newIntTypeNode__ast_u5387((NI64)(a_1 + first_1), elemType_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
				(*aa_1).info = info_p3;
				{
					if (!(a_1 == b_1)) goto LA24_;
					add__ast_u3215(result, aa_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
				}
				goto LA22_;
LA24_: ;
				{
					tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* bb_1;
					tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T27_;
					bb_1 = NIM_NIL;
					T27_ = NIM_NIL;
					T27_ = newNodeI__ast_u4091(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)44), info_p3);
					if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T27_); goto LA11_;}
					eqsink___ast_u3261(&n_1, T27_);
					if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
					eqcopy___ast_u3381(&(*n_1).typField, elemType_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
					add__ast_u3215(n_1, aa_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
					bb_1 = newIntTypeNode__ast_u5387((NI64)(b_1 + first_1), elemType_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
					(*bb_1).info = info_p3;
					add__ast_u3215(n_1, bb_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
					add__ast_u3215(result, n_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
					eqdestroy___ast_u3252(bb_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
				}
LA22_: ;
				e_1 = b_1;
				{
					LA11_:;
				}
				{
					oldNimErrFin11_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u3252(aa_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					*nimErr_ = oldNimErrFin11_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
LA9_: ;
			e_1 += ((NI)1);
		} LA4: ;
	}
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3252(n_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3378(elemType_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, intersectSets__nimsets_u145)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* a_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* b_p2) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
	tySequence__6H5Oh5UUvVCLiakt9aTwtUQ x_1;
	tySequence__6H5Oh5UUvVCLiakt9aTwtUQ y_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	x_1.len = 0; x_1.p = NIM_NIL;
	y_1.len = 0; y_1.p = NIM_NIL;
	x_1 = toBitSet__nimsets_u73(conf_p0, a_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	y_1 = toBitSet__nimsets_u73(conf_p0, b_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	bitSetIntersect__bitsets_u104((&x_1), y_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	result = toTreeSet__nimsets_u92(conf_p0, x_1, (*a_p1).typField, (*a_p1).info);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		eqdestroy___pureZtimes_u2620(y_1);
		eqdestroy___pureZtimes_u2620(x_1);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, unionSets__nimsets_u131)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* a_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* b_p2) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
	tySequence__6H5Oh5UUvVCLiakt9aTwtUQ x_1;
	tySequence__6H5Oh5UUvVCLiakt9aTwtUQ y_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	x_1.len = 0; x_1.p = NIM_NIL;
	y_1.len = 0; y_1.p = NIM_NIL;
	x_1 = toBitSet__nimsets_u73(conf_p0, a_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	y_1 = toBitSet__nimsets_u73(conf_p0, b_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	bitSetUnion__bitsets_u71((&x_1), y_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	result = toTreeSet__nimsets_u92(conf_p0, x_1, (*a_p1).typField, (*a_p1).info);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		eqdestroy___pureZtimes_u2620(y_1);
		eqdestroy___pureZtimes_u2620(x_1);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, diffSets__nimsets_u138)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* a_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* b_p2) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
	tySequence__6H5Oh5UUvVCLiakt9aTwtUQ x_1;
	tySequence__6H5Oh5UUvVCLiakt9aTwtUQ y_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	x_1.len = 0; x_1.p = NIM_NIL;
	y_1.len = 0; y_1.p = NIM_NIL;
	x_1 = toBitSet__nimsets_u73(conf_p0, a_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	y_1 = toBitSet__nimsets_u73(conf_p0, b_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	bitSetDiff__bitsets_u82((&x_1), y_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	result = toTreeSet__nimsets_u92(conf_p0, x_1, (*a_p1).typField, (*a_p1).info);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		eqdestroy___pureZtimes_u2620(y_1);
		eqdestroy___pureZtimes_u2620(x_1);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, symdiffSets__nimsets_u152)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* a_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* b_p2) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
	tySequence__6H5Oh5UUvVCLiakt9aTwtUQ x_1;
	tySequence__6H5Oh5UUvVCLiakt9aTwtUQ y_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	x_1.len = 0; x_1.p = NIM_NIL;
	y_1.len = 0; y_1.p = NIM_NIL;
	x_1 = toBitSet__nimsets_u73(conf_p0, a_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	y_1 = toBitSet__nimsets_u73(conf_p0, b_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	bitSetSymDiff__bitsets_u93((&x_1), y_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	result = toTreeSet__nimsets_u92(conf_p0, x_1, (*a_p1).typField, (*a_p1).info);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		eqdestroy___pureZtimes_u2620(y_1);
		eqdestroy___pureZtimes_u2620(x_1);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, inSet__nimsets_u8)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* s_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* elem_p1) {
	NIM_BOOL result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NIM_BOOL)0;
	{
		if (!!(((*s_p0).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)39)))) goto LA3_;
		result = NIM_FALSE;
		goto BeforeRet_;
	}
LA3_: ;
	{
		NI i_1;
		NI colontmp_;
		NI i_2;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__ast_u3190(s_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		i_2 = ((NI)0);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA7;
				i_1 = i_2;
				{
					if (!((*(*s_p0)._kind_6.sons.p->data[i_1]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)44))) goto LA10_;
					{
						NIM_BOOL T14_;
						T14_ = (NIM_BOOL)0;
						T14_ = leValue__astalgo_u79((*(*s_p0)._kind_6.sons.p->data[i_1])._kind_6.sons.p->data[((NI)0)], elem_p1);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						if (!(T14_)) goto LA15_;
						T14_ = leValue__astalgo_u79(elem_p1, (*(*s_p0)._kind_6.sons.p->data[i_1])._kind_6.sons.p->data[((NI)1)]);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
LA15_: ;
						if (!T14_) goto LA16_;
						result = NIM_TRUE;
						goto BeforeRet_;
					}
LA16_: ;
				}
				goto LA8_;
LA10_: ;
				{
					{
						NIM_BOOL T21_;
						T21_ = (NIM_BOOL)0;
						T21_ = sameValue__astalgo_u63((*s_p0)._kind_6.sons.p->data[i_1], elem_p1);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						if (!T21_) goto LA22_;
						result = NIM_TRUE;
						goto BeforeRet_;
					}
LA22_: ;
				}
LA8_: ;
				i_2 += ((NI)1);
			} LA7: ;
		}
	}
	result = NIM_FALSE;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, overlap__nimsets_u32)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* a_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* b_p1) {
	NIM_BOOL result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NIM_BOOL)0;
	{
		if (!((*a_p0).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)44))) goto LA3_;
		{
			NIM_BOOL T9_;
			if (!((*b_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)44))) goto LA7_;
			T9_ = (NIM_BOOL)0;
			T9_ = leValue__astalgo_u79((*a_p0)._kind_6.sons.p->data[((NI)0)], (*b_p1)._kind_6.sons.p->data[((NI)1)]);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!(T9_)) goto LA10_;
			T9_ = leValue__astalgo_u79((*b_p1)._kind_6.sons.p->data[((NI)0)], (*a_p0)._kind_6.sons.p->data[((NI)1)]);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
LA10_: ;
			result = T9_;
		}
		goto LA5_;
LA7_: ;
		{
			NIM_BOOL T12_;
			T12_ = (NIM_BOOL)0;
			T12_ = leValue__astalgo_u79((*a_p0)._kind_6.sons.p->data[((NI)0)], b_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!(T12_)) goto LA13_;
			T12_ = leValue__astalgo_u79(b_p1, (*a_p0)._kind_6.sons.p->data[((NI)1)]);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
LA13_: ;
			result = T12_;
		}
LA5_: ;
	}
	goto LA1_;
LA3_: ;
	{
		{
			NIM_BOOL T19_;
			if (!((*b_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)44))) goto LA17_;
			T19_ = (NIM_BOOL)0;
			T19_ = leValue__astalgo_u79((*b_p1)._kind_6.sons.p->data[((NI)0)], a_p0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!(T19_)) goto LA20_;
			T19_ = leValue__astalgo_u79(a_p0, (*b_p1)._kind_6.sons.p->data[((NI)1)]);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
LA20_: ;
			result = T19_;
		}
		goto LA15_;
LA17_: ;
		{
			result = sameValue__astalgo_u63(a_p0, b_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA15_: ;
	}
LA1_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, emptyRange__nimsets_u219)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* a_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* b_p1) {
	NIM_BOOL result;
	NIM_BOOL T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T1_ = leValue__astalgo_u79(a_p0, b_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	result = !(T1_);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, deduplicate__nimsets_u186)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* a_p1) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
	tySequence__6H5Oh5UUvVCLiakt9aTwtUQ x_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	x_1.len = 0; x_1.p = NIM_NIL;
	x_1 = toBitSet__nimsets_u73(conf_p0, a_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	result = toTreeSet__nimsets_u92(conf_p0, x_1, (*a_p1).typField, (*a_p1).info);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		eqdestroy___pureZtimes_u2620(x_1);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
